@@ -16,13 +16,13 @@
 // Copyright (C) 2005 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2009-2016 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2010 Christian Feuersnger <cfeuersaenger@googlemail.com>
+// Copyright (C) 2010 Christian Feuersänger <cfeuersaenger@googlemail.com>
 // Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
 // Copyright (C) 2011 Andrea Canciani <ranma42@gmail.com>
 // Copyright (C) 2011, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2012, 2015, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2015, 2016 William Bader <williambader@hotmail.com>
-// Copyright (C) 2018 Stefan Brns <stefan.bruens@rwth-aachen.de>
+// Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -32,7 +32,6 @@
 #ifndef SPLASHOUTPUTDEV_H
 #define SPLASHOUTPUTDEV_H
 
-#include "goo/gtypes.h"
 #include "splash/SplashTypes.h"
 #include "splash/SplashPattern.h"
 #include "poppler-config.h"
@@ -400,32 +399,30 @@ private:
   void setupScreenParams(double hDPI, double vDPI);
   SplashPattern *getColor(GfxGray gray);
   SplashPattern *getColor(GfxRGB *rgb);
-#ifdef SPLASH_CMYK
   SplashPattern *getColor(GfxCMYK *cmyk);
   SplashPattern *getColor(GfxColor *deviceN);
-#endif
   static void getMatteColor( SplashColorMode colorMode, GfxImageColorMap *colorMap, const GfxColor * matteColor, SplashColor splashMatteColor);
   void setOverprintMask(GfxColorSpace *colorSpace, bool overprintFlag,
 			int overprintMode, const GfxColor *singleColor, bool grayIndexed = false);
   SplashPath convertPath(GfxState *state, GfxPath *path,
 			  bool dropEmptySubpaths);
   void drawType3Glyph(GfxState *state, T3FontCache *t3Font,
-		      T3FontCacheTag *tag, Guchar *data);
+		      T3FontCacheTag *tag, unsigned char *data);
 #ifdef USE_CMS
   bool useIccImageSrc(void *data);
   static void iccTransform(void *data, SplashBitmap *bitmap);
   static bool iccImageSrc(void *data, SplashColorPtr colorLine,
-			Guchar *alphaLine);
+			unsigned char *alphaLine);
 #endif
   static bool imageMaskSrc(void *data, SplashColorPtr line);
   static bool imageSrc(void *data, SplashColorPtr colorLine,
-			Guchar *alphaLine);
+			unsigned char *alphaLine);
   static bool alphaImageSrc(void *data, SplashColorPtr line,
-			     Guchar *alphaLine);
+			     unsigned char *alphaLine);
   static bool maskedImageSrc(void *data, SplashColorPtr line,
-			      Guchar *alphaLine);
+			      unsigned char *alphaLine);
   static bool tilingBitmapSrc(void *data, SplashColorPtr line,
-			     Guchar *alphaLine);
+			     unsigned char *alphaLine);
 
   bool keepAlphaChannel;	// don't fill with paper color, keep alpha channel
 
